arm_nop_buffer

Function arm_nop_buffer 

pub fn arm_nop_buffer(arch: Arch, len: usize) -> Result<Vec<u8>>
Fill len bytes with the architectural NOP encoding for arch.

len must be a multiple of ARM_INSTRUCTION_BYTES; otherwise the resulting tail bytes would be a partial instruction and the CPU would fault on execution.

Errors

Returns Error::Parse if arch is not an ARM ISA or len is not a multiple of 4.